/*

Process steps
	1. Import SADE CSV file into SAS.
	2. Parse SAS file by geography.
	3. Add county id and name via format, if geography is census tract.
	4. Add school district id via format, if geography is school district.


Geography:
	State: State
	County: County
	Tract: Census Tract
	Cd: Congressional District
	Sldu: Legislative District
	Sduni: School District

Origin:
	1 = Non-Hispanic
	2 = Hispanic

Sex:
	1 = Male
	2 = Female

Race:
	1 =	White
	2	=	Black or African American
	3	=	American Indian and Alaska Native
	4	=	Asian
	5	=	Native Hawaiian and Other Pacific Islander
	6	=	Two or More Races

Age: 
	1	=	0-4
	2	=	5-9
	3	=	10-14
	4	=	15-19
	5	=	20-24
	6	=	25-29
	7	=	30-34
	8	=	35-39
	9	=	40-44
	10 =	45-49
	11 =	50-54
	12 =	55-59
	13 =	60-64
	14 =	65-69
	15 =	70-74
	16 =	75-79
	17 =	80-84
	18 =	85+ 


******************************************************************/

/*****************************************************************/
/*****************************************************************/

/*define the following parameters*/
%let csv_path = c:\temp\sadetmp\csv;
%let csv_filename = sade_all_2000_to_2010.csv;
%let sas_filename = sade;
%let format_path = c:\temp\sadetmp;

/*****************************************************************/
/*****************************************************************/

/*you should not need to change anything below this line*/
%include "&format_path.\sade_import_csv_formats.sas";


/*import csv file into sas*/
data work.&sas_filename.;
	infile "&csv_path.\&csv_filename." delimiter = ',' missover dsd lrecl=32767 firstobs=2;
	informat Sumlev $24. Geoid $12. Area_Name $42. Origin 1. Origin_Lbl $14. Sex 1. Sex_Lbl $6. Race 1. Race_Lbl $42. Age 2. Age_Lbl $7. Pop 10.2 Year 4.;
	input Sumlev $ Geoid $ Area_Name $ Origin Origin_Lbl $ Sex Sex_Lbl $ Race Race_Lbl $ Age Age_Lbl $ Pop Year;
	format Sumlev $24. Geoid $12. Area_Name $42. Origin 1. Origin_Lbl $14. Sex 1. Sex_Lbl $6. Race 1. Race_Lbl $42. Age 2. Age_Lbl $7. Pop 10.2 Year 4.;
	label Sumlev="Summary Level" Geoid="Geographic ID" Area_Name="Area Name" Origin_Lbl="Origin Label" Sex_Lbl="Sex Label" Race_Lbl="Race Label" Age_Lbl="Age Label" Pop="Population";
run;

/*parse sas file by geography*/
%macro parsebygeo (geo,sumlev);

	data &sas_filename._&geo.;
		set &sas_filename.;
		where sumlev = "&sumlev.";
	run;

	/*add county id and name from format if geography is census tract*/
	%if &geo. = blkgrp or &geo. = tract %then %do;
		data &sas_filename._&geo.;
			set &sas_filename._&geo.;
			format County 2. County_Lbl $15.;
			county = substr(geoid,3,3);
			county_lbl = put(county,county.);
			label county_lbl = "County Label";
		run;
	%end;

	/*add school district code (ccddd) from format if geography is school district*/
	%if &geo. = sduni %then %do;
		data &sas_filename._&geo.;
		retain sumlev geoid ccddd;
			set &sas_filename._&geo.;
			format CCDDD $5.;
			ccddd = put(geoid,sduni.);
			label ccddd = "School District ID";
		run;
	%end;


%mend;
%parsebygeo(state,State);
%parsebygeo(county,County);
%parsebygeo(tract,Census Tract);
%parsebygeo(cd,Congressional District);
%parsebygeo(sldu,Legislative District);
%parsebygeo(sduni,School District);
